@@ -473,8 +473,8 @@ def _find_revert_offset(
             pc_list[-1].update(
                 dev="Cannot send ether to nonpayable function",
                 fn=pc_list[-8].get("fn", "<unknown>"),
-                offset=pc_list[-8]["offset"],
-                path=pc_list[-8]["path"],
+                offset=pc_list[-8].get("offset"),
+                path=pc_list[-8].get("path"),
             )
             return
 
